#!/usr/bin/env python
"""
    Images stored as PhotoImage objects, for buttons and logos.
    Created Oct 2008
    Copyright (C) Damien Farrell

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
"""

def tableapp_logo():
     import tkinter as tk
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhhwGAAcZ1AAAAAAgLIQgNJQgPJQoOKggRJgsRLgoTLggVKAoWMAgY'
            +'KQobMgofNAgdWAgkLhUfWgwpLxAsLwotOhglYhgmYhMtLxombxcpZBgvLRAz'
            +'Ox4xLRYwZx0teRQ3OyU0LR0veRg5OxwzeyEwix87ORU5ay44LC84KyIyjxY6'
            +'bDM5KzU6KyY+OBw8fyU5lxVCcC5BOCU7lyRAmiRBmjpGNztGNhtIhUBINkJJ'
            +'NiNLnxpSihZhfSJapiFmrCJufyt2fxt4mzV6fkF+ekN/eyqInFKFeTWSnSKW'
            +'wWKLeCSYwUGXnCicwS6jwlKdmC+kwn2WdjGlwn6WdYSYczWqw4qbdDesw2Wk'
            +'ljmtw46ddJyhe0K2xHmslKSkpFC7wlK8wpq5kWfEvpy5kKW9kKq/kHrLvLDB'
            +'j37Nu47TusTExMPJmcXFxZfWuZ7ZuM3NzcDmtcLntMTotM7ss9Tus9vxsvP6'
            +'v///2f///////////////////////////////////////////yH+EUNyZWF0'
            +'ZWQgd2l0aCBHSU1QACH5BAEKAH8ALAAAAACHAYABAAf+gACCg4SFhoeIiYqL'
            +'jI2Oj5CRkpOUlZaXmJmam5ydnp+goaKjpKWmp4VbaWysra6vsLGys7S1tre4'
            +'ubq7vL2+v8DBwsPExa1pW6moy8zNzs/Q0aXJg2cAWGjZ2tvc3d7f4OHdVRpV'
            +'5ufo6err7O3u6x8CH/P09fb3+Pn6+/heJV4AAwocSLCgwYMIC3IQwKGhw4cQ'
            +'I0qcSLGixBoIamjcyLGjx48gQ4r8SAKAtUFsAKCZw7Kly5cwY8qcSRNmmRVl'
            +'curcybOnz59Ag/qEYQCG0aNIkypdyrSp06VtZrSZSrWq1atYs2rdirWFgRZg'
            +'w4odS7as2bNoy+5YsKOt27f+cOPKnUu3rtwaAFKiVFmzr9+/NW8KHUy48GCi'
            +'TxMrXpw4KtfHkCM/9pq2suXLldfa3cy582a8egWlXAm4tOm+gg2rXk0YMePX'
            +'sBU7lky7NmTKmHPrtqzZs+/fnEETGn26uHGXqVkrX67Tdezn0I/Otk29OlXc'
            +'u7NrD9sbuPfvboXvJX28fOkyRJirVw6DQvT3z9s4sU6feosJ2/Nn34ECvH/v'
            +'4onGl3kE+rXegavBpyBs9TVYm34Q6vbfhL8FmNeABWYoE4Ictrbgh405KOJk'
            +'EZaYGYUofnbheBq2aFOHMP4E4oxNjWijVibmeFaKPNJlIXEuBjlHjETyROOR'
            +'Sd3+qKRVOjY5Vo9QwvUjhkJqWOSVZSCpJQxLdtmGk2C2EOWYO0xJXpUZYlnk'
            +'lkh6uWSYTpIZpZlotqgmkWwe6aaScDYpJ5R01pnmnTDmSeOeN/ap4589Bioo'
            +'gYQWaiiIiNqoaI6M8ujoo+VF2uGklFYq4qUmZprippwa5ymHoH4o6qikRmgq'
            +'iqimetqqCLa64KsOxirrrBPWaut5uK6nq4K8NugrhMAGu6KAZw5rWrHGHvte'
            +'svUtq1+z/wkrrYHUMmfttdhap21+3Prn7beBhbvcuNGVa+652qUL3rrszuTu'
            +'u/DGJ6999O5nL4DPXhhtvqjty1q//v77YMC7DUxwaAb+I0yswqoxHJvDtkEc'
            +'scQVFgykxeBibJjGDHJMm8cSguwbviQjZ/LJKDOm8sosY+byyyJTGbO+MxdW'
            +'s803R5azzjt3BvPPQwbt4dAhFk3i0ScmrSLFIzO9odOHQR211FtRzZvVVw/n'
            +'s9Yvcd21106BPbXYO5Jt19I/qy0U20+5zRXcack9d88Ho92S3UHh3bbeOPId'
            +'t99z0R0z4UAZXiPiWSm+OONxOU4y5DJKDhXlXVmuFuZ3AS741pwb6blSoIcu'
            +'+pOkZ2766S+mvtPqrLfO5Ouwx/6W5hbbrjru0uleFe+9+94W8AgLfzvxxRs/'
            +'FfJiKf/77LTL7HyW0Bsl/XX+1INlfXjYZ8/S9jl17/33X4Yv5vhllm8++tx3'
            +'z3774cMfP9Zn006/+lxin/veNz7m5et/6rvfAPVnQHYh0H4CdB8D5Ze9B0JP'
            +'gRKEXwO/ZUHiYTB/GqSg/9AHwA9Sb4L8C9zpOog7EyIPhWZToeBYuDoX8g6G'
            +'LDLf4EiYwAiCsIAiXCEPIfi9BYYwhTrc4fZK6MMTHjGGSTzfEC/YxBc+MYdJ'
            +'pKHnbPg6HEIrik1bYg+LmEEgIjGKWpQcF0XnxYqhcYoerOINr/jFN4qRiNIz'
            +'ohmhaEfnMZGMP7TeBqWVRsOt0XJtzNr84NhCOXaRjheKQAcm2QEfZOGSmMyk'
            +'Jjf+yclOevKTWaCDKEdJylKa8pSoTKUqU4mEVrrylbCMpSxnScta0nINuMyl'
            +'LnfJy1768pfA/OUThknMYhrzmMhMpjKXqUwcOPOZ0IymNKdJzWpaE5obSIA2'
            +'E1CAnhUBlOAMpzhBucpymvOc57SlOtfJTnYG853wjGc8mUnPetrTntfMpz73'
            +'uU8WeHOcAA1oONFJ0IIStJ0ITShC5cnQhjL0nhCNKET5SdGKUtSf/PumQDfK'
            +'UUwa9KMgPaVCR0pSWTr0pCjtpURXylJkWvSlMJ0mRs2m0Y7aFKAhzWlIS8rT'
            +'kqb0pyltqVBbGtOixnSme6npTZdKTp069aA9jepCgUr+1YcO9aoTNapWL/pP'
            +'pnrVk08NqzmlStZ1VvWs8MSqWuu51bbqE6kCUupX53pJsdqVlWXN6yzRyldh'
            +'rvWvyXSrYKsJ1wvJla5fvatiS6nXxsKyr5DdJWAna8zBWjaahU3JYRHL1MV6'
            +'lg6ODS0SIkvaNVD2tE+4rGpxkFkAbJazN/3sYkXr2NJGFrWUXe1lW/ta2HZU'
            +'toqlbWNtC1ncTla3luWtb+cK3LsKV6/E7atxAYvcwSp3uV5trl2fm9fo8nW6'
            +'f62uYK+L3aVqV6zcLat30QretYrXreQtr03PG9b0knW9Z22vWt/b1vjKl6P0'
            +'fap9pYrfquoXq/zdqn//K9D+ADt1wFEtMFUPfNUEa3XBDMapg3MK4Z5KGKgU'
            +'HqqFjYrhDItzwxzusE8/HNQQE3XER+2qiRuMYpCqeMUsPqmLXwzjl5Z4xk2t'
            +'sUFvTNIco3THLO0xTH8MZLAKechEVqiRdYxkiSrZxzJu8omfXNAoS3nKDa2y'
            +'la9cUSZreZNc7rKXpwpmeYo5omQuc5bPHOQ0j3XN7WyzVd+Mzzjz08x09qid'
            +'04lnd+p5nnzus5/fOudAd3LQhC60Og+N6ETTc9H9bLSj0QzpckrarJR+p6XZ'
            +'iul8AtrRnfb0p20ZalGPmpmlNrWmN53JVK9y1axuNTBfDetYW/PUgba1KnFd'
            +'S13+75rXzfQ1YWdN67oKG5XEvqWxfYnsZCtbpsxu9rOhHW2TTlul1XbptbGd'
            +'0WY7eduM7XYsvw3ucFd23NIENp3RbUp1r5vdknX3u+ENTXmfmd7ptrcr8Z1v'
            +'fROT35jNNq0BTkqBv5LgujR4MRHeb4VvmuGjdPjAIY5LiR+c4s70t5YxLkqN'
            +'t5LjHfd4akHOWoujmuQmHy3KVb5ykIu8ySQHrclRblqVs7zl5TY3J3Mec57T'
            +'/Oc3BzLRdz5zn7M86TNeusaN7nSbuzzYMGc6x4/+9KvPO+tTb7rHke71f4Pd'
            +'4VQfe9eDLnRNSh3tYpc42dnedkFjvOhxN/jcaVp3t5/+XeBpl/va+d53uzMc'
            +'71uvOsWhbuK3Az7v+t57UgtveIAjHuJctzrd++54ewde74OfPOVD+XfPQ97d'
            +'ko/r6El/d61jXvEIZ3yGO6/uz0c+9KofPe27bXvU496wq999tHsf7tQDX/el'
            +'r/3pi/97zQY/+bxffrWN73zktz7siVe75s3mgRd4/wVHUIP4x0/+8pv//OhP'
            +'v/rVcIL2u//98I+//OdP//rTXwn4z7/+98///vv//wD4f00wgARYgAZ4gAiY'
            +'gAq4gAooAw74gBAYgRI4gRRYgRZYgVKQgRq4gRzYgR74gSAYghvYAxlQghkA'
            +'AT2jBeu3gizYgutnfzAYgzL+KIMBWIM2eIM3yIA6uIM8yIMX+INAGIRBKIJE'
            +'WIRGaIRDkIIuuIRMyIIz+IRQ+IQ4OIVUOIU9eIVYeIVCuIVcuIVH+IVg+IVJ'
            +'yD8q2IRmeIbjF4VquIbyV4Vu+Ib9l4VyOIcI2IV2eIcTGIZ6uIceOIZmU4Zo'
            +'GIhLyIaEyIZweIhwSIeKSId42Ih4yIeQyId+uBeAKIiW+IKFmIlSiIicaIWL'
            +'+Ila6Iii6IWRWIpiqISXmIrpp4msGIOd+Io2CIqyuIOjWItAaIq4WISTKCCV'
            +'qIq+KH6tGIz3B4vE6H+zeIwNaIvKSIG52IwguIsX0ou/qIrCWI3wV4zYuH/I'
            +'uI3+BriM3hiBzhiOHAiNKSGN03iJ1piOJ5CN7KgE3PiOTfCN8igD4liPUkCO'
            +'AGCO5yiI6miN7ZiN8MiN8/iN9iiO+KiP+4iG/ViN/4iNAbmNA+mNBRmOB5mQ'
            +'vriQwtiQxfiQyBiRyziRzliRFpmKGBmMGkmMHHmMHqmMINmMIjmSlliSrXiS'
            +'sJiSs7iSttiSufiSMBmIMsmKNPmKNimLOFmLOomLPNmTZ/iTmhiUnTiUoFiU'
            +'o3iUppiUStmETJmJTsmJUPmJUimKVFmKVnmVg5iVhLiViNiVi/iVjhiWkTiW'
            +'ZNmCZnmWaJmIasmIbPmIbimJqBiXWDmXa1iXdnmXcpj+l3q5l3oIl36JiYAZ'
            +'hYL5hoQ5h4Z5h4i5h4q5mKvYmI75mFUYmYU5mV1YmYnZl5gpl5oJhZzZmZ6J'
            +'haAZmqIJhpdZmuZ3mqiZmp64mj3Ymlz4mrBJmrLJmLTpiraJg7gZiro5hLx5'
            +'hLH5m2kYnDQ4nDlYnD54nMiZnLrom8yJfs75nNBZg9I5ndT5g9aJhNiZnbO5'
            +'nTDYnbH4nToYnrc4nkS4nNmJnumpngHInu3pnhcIn/FZnuZJfvRpf/Z5n/i5'
            +'gPq5n/wZgvLJnAFafwMKgAVqoAeKgQn6jP75n8DYoPP3oAIYoQk4oRRaoX14'
            +'oRiqoRvKoXHooXUIonkooiP+SoYYmpkmeo0oyn8quqIsCo4u2oEL+pszGn81'
            +'aqM32o05qqM7uoE9Kps/SqNBmn9DSqRF+oBHOo4k+p9L+n5Nqn9PWoBRCoFT'
            +'iqRVap5X6n5Z6qRbOoBdKqVfmoFJWppj2n5lin9niqZpSo9reo9hOp9vGqfu'
            +'OKd1aqdr2qaY+abrGKdzGo91eqd4CqMxen6EyqeH+qeKKqiL+aiG6qeJeqeU'
            +'6peWWqaRmqmBmqcMuqeXeqaSqqmi6qOk6qmYmqaTmqpKuqpZ+qmuiqqM2qjl'
            +'16mz2qpd+qq3iqvNOaaQyqtR6qt/CKy5KqtNSqu9aqvHiqzBeqXDaqqg+qWb'
            +'Gpf+urqsxFqkxkqJ0BqtSzqtW3qqofqryJqtQcqsxeqs3vqt7Kes6bqtOdqt'
            +'vOiu7yqspTqu1Tql10qW6Fqj6sqt7Fqv7vqvKBqw8zqw0WivBsuhCMui9Lqw'
            +'BQuvACuvEKuw5ciwFHuwFguiEZuxE4uvrEqttVquZmMCNJCyNAAFbtCyLvuy'
            +'MBuzMjuzNFuzbkAFOJuzOruzPNuzPvuzQPuzZjC0RFu0Rnu0SJu0Sru0StsA'
            +'Tvu0UBu1Uju1VFu1Vlu1XJC1Wru1XNu1Xvu1YBu2YNsFZFu2Znu2aJu2aru2'
            +'bGu2QAACcAsCFdAzYGCzdnu3eGuzQbu3fNu3fcu0gBv+uIIruFdbuIZ7uIcr'
            +'toq7uIzLuG37uJAbuZGbBHSbt5Z7uXfrt5q7uZo7uJ77uZ6LuKI7uqLbuKZ7'
            +'uqYruaq7uqpLufxTt5gbu7Lrspxbu7bbs6Cbu7qLtKTbu747tagbvMLrtaxb'
            +'vMabtq5rNrA7u8xrubf7vLe7u9K7u79bvb87vNg7vMe7vcebvHuxvM0bvnoL'
            +'veTbudN7vqFrvepbutnbvqnLvfDbupUrvvRLs+V7v3yLvvobuOvbv4brvgC8'
            +'uPE7wJDrvQICvvWbwC2LvwwstPv7wEnrvxKMtQFcwV9LwBi8tgZ8IQiswPXb'
            +'wCC8sxA8wkY7wSYctRacwlz+m8EsfLYbnBId7MHiG8I0TAUkfMNmcMI63AAq'
            +'3MNc0MJA3AUvDAAxLMPNW8MhjMMkvMMn7MMqHMQtPMRFbMSzi8QgrMQjzMQm'
            +'7MQpDMUsLMVUnMBW3MBYDMFaPMFcbMFenMFgHMb0O8YMXMYPfMYSnMYVvMYY'
            +'3MZuHL5wjL9yvL907L92HMB4TMB6vMfM28f3+8f6G8j9O8gAXMgDfMiILLuK'
            +'XL6MjL6OvL6Q7L6SHL+UXMmYe8nkm8nnu8nq28nt+8nwG8qi7Lyk/LymPL2o'
            +'bL2qnL2szL2u/Mp4G8uyPMvUW8vXe8vam8vdO7+8PMq+bLvAHMzC3LvEXMzG'
            +'XLz+u5zM47vMnNvMuvvMvhvNwjvNxlvN1my/2JzN2gy63AzN3oy64EzNyDzO'
            +'vVzOm3vO6JzOo7vO7NzOqyvO8Byz8jzP9Jy+9oy4+Hy6+rzP79zP1/zP+RvQ'
            +'gzvQ7FvQjnvQksvPCk27DP23Dk24EJ24Ej3RFF3ACX3RM5vRGr3RgNvRHv3R'
            +'ihvSkzvSJO3PJr23KM2/Kl24LC3ALv24Fk3SM03TNc20N43TOS22O83TMB3T'
            +'L/vTQRvUQj3UVlvURn3UbNvTF83UQOvUSwvVUS3VY0vVGpzUSr3AWO2zWt20'
            +'XE21Xv3VYI28Yj3WZW3WZ827aQ28a028be3WrzvW5Bz+1yI810db13Z91yuc'
            +'12hr1Qrt1zwL2IEt2ChM2IVt2GaL2P2s2H/N2ETr2I8N2Vor2S781kpt2TqL'
            +'2UWr2VDL2Vvr2ZMN2jEt2jlL2plt2k6L2p2t2mRL2fDs2jgL20Mr27NN2z9s'
            +'20LM2j6t27ydw74N3MFt27g9zrptw7zt2zwM3MI93HvN1zL73Mct3cpd3c1t'
            +'zdod3clN3cL93ckc3rDN3eTN3MR91cYt3rLd3eXd3on93uk93rTt3fRd2fZN'
            +'2uqd3/N93dgNs+jt3/iN2vot4AOO0a693QfO2QmuvAtO4P2N2f+N4AEu4RPO'
            +'4KLt4PG93qpt3rxc4Bb+4JD+HeHfu+Ecbtkebtryzd4KPuEkztgXDuEZnuIq'
            +'frMVTuMmTtgofsA5ruMNDt8uDuKeLeKvPOOAXeMnfuNAnuNKPtdM7uNOzsFB'
            +'HuVnPeV3/eNWDuU7vuQ9vuVVDsNX/uVSHuZrzeUpgbIqy7IDjuVareVpbthv'
            +'G7dzyz9iEAd6vud83ud+/ueAHuiC7udWUOiGfuiInuiKvuiM3uiMvgSQHumS'
            +'PumUXumWfumYfulvsOmc3ume/umgHuqiPuqiPgamfuqonuqqvuqs3uqu3uoi'
            +'EOuyPuu0Xuu2fuu4nuu4bgE9k+eD/uvAHuyC7ujEXuzGbuyZnuzKvuzLTurO'
            +'/uz+0A7trz7t1F7t1a7r2J7t2q7tvI7nwv7t4A7sxz7u5D7uzH7u6H7u0b7u'
            +'7L7u1v7u8P7u2z7v9D7v3W42vh7u+r7vel7u/v7vip7uAj/wld7uBn/woB7v'
            +'Cr/wq17vDv/wtn7ve5Hv/F7xwg7wGA/wBL/xBI/wHo/wDB/yDA/xJA/xEi8g'
            +'FG/xKj/sGd/y5s7xMK/uHz/z7i7yNi/vJZ/z9t7rK9/zLO/yQO/oMT/0yk7z'
            +'Rv/sN5/01K7zTJ/tJ38hKe/zUh8HQV/1j070WG/pR7/1pa70Xs/qTR/2u87z'
            +'U1/2VG/1aH/oWb/2k871bu/pXx/3qS72dE/rT58SUW/+9iqf9nxvBWz/90vw'
            +'9oL/BnJf+GNQ94gvAncPAHmv9xXf92kP+Gw/+G9v+HKf+HW/+I3v+PsO+Wgv'
            +'+WtP+W5v+XGP+XSv+Zzv855v9aCf9aLP9aT/9aYv9qif+iu/+lXf+lj/+lsf'
            +'+14/+2Ff+7Zv8bgf9LpP9Lx/9L6v9MDf9MI//Pxe/EB//EOf/Ea//Enf/Ez/'
            +'/NCv79Lv8tQf89ZP89h/89qv89zf/eD+/S0f/jA//jNf/jZ//jmf/up/8eyP'
            +'8e7P8fD/8fIv8oAgIjhIWGh4iJiomGgBwAYA6QggFldpeYmZqbnJ2ZlpBRoq'
            +'OkpaanqKerq0ytrq+gobKzv+K/tme4ubq7vL2+vbOxYsPExcbHyMnIy8yNzs'
            +'7Nz4GPlI6Wl9jd2Zus3d3U0LHi4u/ltufn6urL7Ozv78Dv8eHSlZnX2P7+m9'
            +'z78//g/wH7qBBAe2O4jwYLyFDA/NmzYpn8SJl/pZvFgqoMaNsAp6/LgrociR'
            +'xhqabPgQEjWKLPNhfImRo0yOIGuCJImT5Mmd8FLWawkUG8yh/GYaBWgzKcGc'
            +'TBHyfNrM58qgVDkRvcrtqNZwSruaawp2HdSxjCRBtFc1rSWsbFVtfRvLq1xg'
            +'YeseI4u3kNSIavvGaQt4FNzBruYazmU3MbG8jEXsReuXauDJVghbXnI48xvF'
            +'nMf+NM77OLJayoEvE9Z8uLPiz3hDi65KGrDpwagNq07Mmqzr10Fjt50Nt/bc'
            +'23Zzj93Nu6VvtsDfCpdLvK5xqMiTU1yOtfnW516jh53+tLp1idivatfKvat3'
            +'sOB5ih+PrzzR80fTK13ftP3O9/CzyR9Kn1H2JYUfU/qdxF9/1/wHU4AzDWhT'
            +'gTkdaFKCCurDYEwO0gThTRLqRCFDFl5oVYYXbchhhx59CGKI8YxIoiYmnoii'
            +'Rip+xOJILi4EY4yYzGhRjTbeWFCOIu34olkq8eWjUEAWJSRSRC5lpFNIyqPk'
            +'T006+aQ3UUo5JTpVWnklNFlOtaU1Xfrz5ThhGjRmO2X+PtNjmmt62SY5b6YT'
            +'pztzRnUmk2lqc2dWeXK151d9ivUnM3VuWaihh9KSqKKLKtOoo4FCNqiMkaYy'
            +'KTiVlnOpOpku8miTn4Ia6iyj/lIqpqeWJc2SnHb646putRrXq3TFetesiKTq'
            +'o6678vqKr78CW4yww26KK6HGkoJsr8rqwmywzuoFbbSbTJtRtclei222zW7L'
            +'ba1aevsJuIKJWxi5iJm7GLqEEBuju+/Cy4q889IrjL33dsturvqCwm8r/uIC'
            +'8DACD4IviQeHknC/C9vScMAPO0ZwwWtNXFnFmF28WcaebRzxhSCHXDHJJWe8'
            +'McfqoulxJSuLPPLFJp/8cMr+Ct4ssss7x7xXCjYcbcMUHgPdMslDb/sAAVIT'
            +'EECgYcCBddZab811115/DTbXRoxNdtlmn4122mqvrTYPbr8Nd9xyz0133XbX'
            +'LUfeeu/Nd99+/w144IDHQHjhhh+OeOKKL8744l88Dnnkkk9OeeWWX245E1aH'
            +'zXnnnofNduiijz763aafjjrqgq/OeuutNw577LLLjnnttt9+u+YzA3D1577/'
            +'zjnpwg8vfOrGH2+868ovr/zszj/vPO7STy+97vQ80jvw2m+PNfHef4828uKP'
            +'Pzfz5p/vN/Tqr5849e6/T7n1EGXPff2fg48/+OTvTz76/qPPvgCyD34EhJ/8'
            +'lkT+P/spEGz5a+Dw+AfB4/1vgssToAWfV8AMTu+AkkjgAj+4NQeKUHQRLOHp'
            +'KIhC1l1whbHToAttx0HsgXCGYhuhDdNmwhziLYU8/BsLf+i4FwqxcjHkHQ2P'
            +'2L0bKrFsOmxi3HoIRb4BcYqHG6IVJVdEDyJRgUvsohGcCEYeRHGMcqCiGWNw'
            +'xTR+IYtbpKEXlxhGJ5IximekohqvyMY2gvCNSoxjE+cIxTpO8Y5WzKMeF8jH'
            +'G/pRh4DsoSCBSMghGvKQ9kukDReZw0by8JE/jKQQJ0lJ7llyhJg0oSZTyEkW'
            +'evKFoAyl9kYpwlKW8JQoTOUKV+nCVrryd7B0oCwjSEv+CtrygrjUoC53eb9e'
            +'5u+XEAzmBIdpwWJm8JjI7Jwyl8nM/Tnzf9AUoDQLSM1qgu6a+stm/7YJwG4O'
            +'8JsG3Jw4gUfOcppTfOhMpzrVx8527k6L7xxnPIk3z/HV83z3XF8+3xfOfnbt'
            +'n94LKD0HyryC4vOg1EuoQkPI0Ac6VIIQraBEMUjRDbrzotbMaPE2mryONu+j'
            +'0Qtp9UZKUn+alIQoTZ1KV8pS2rkUdxaNKRxmSrqa2vSmr8upTncKQ5j61GtA'
            +'LZ1QT0hUFRq1hUhN6j6XKtOmtu2ppouqVKfauKpa9XpGxOrXtBo6rnbVq4ID'
            +'K+zEWruexhStbFPr3djaVrf+Mg6umJMrSem6NrvaDa+B0+te+Zo5pZpVa4Dd'
            +'qmDLR1gfGlZxiE3sVRe70MaG77GQjWzfJkvZysZPsZj9qWbPxtnOenZvoG2f'
            +'aCfn14ueFrWpfeJqpdjaKr4Wi6TF7GzNVlvb3lZvudXtbiEXW4X+lonBfdtw'
            +'WVvcwh03csnt53LJ1lznPjdv0ZXudB9X3Xded2zZddt2udtdNH53jb1d7Hi/'
            +'WN7zljG962XvZUvL2PGWV4znTa96vxtecb53v/L1b30DXM0Bx7e/9F0vgpGp'
            +'4OwWuMEAbq9ZI9zcCXf3wBbGKoaDq+Hocvi++E3idQnM4A07uMNL/XBtQ1zc'
            +'EZP+lZ/u1e+Ct2vgFZO4xC5OLYxzK+P5lTi/J77xc3Nc4R3jt8ec/XFrg4zA'
            +'IWeNyY91Mmih3EEpm3i5KMYxhaf74F1SWbBWniyWZahlI+jgxC6Q8BVwfIEN'
            +'CyHJM9byTyVwYgZI+AY4PsCGR0BnIacZz1zWc4b5fGQ/ixjQYGaxT41A6N/y'
            +'wNAgRvRwY6DoGDP6uGF2JaTzvOc+/znQkDgDAKIQhlSretWsbrWrXw3rWLf6'
            +'Bw74ga1vjetc63rXvO61r3edAwXkYNjELraxj43sZCt72cgmgwrIAO1oS3va'
            +'1K62ta+N7WqHYAAh6La3vw3ucIt73OQut7iZgAEmqHuB3exut7vfDe94y/vd'
            +'QQBAGuixBXroe9/87re//w3wgAt84AQvuMEPjvCEK3zhDG+4wx8OcYHnG99p'
            +'YIPFL47xjGt84xzvuMc/DvKQi3zkJC+5yU+O8pSrfOUsb7nLX37xM0w84jSv'
            +'uc1vjvOc63znPO+5z38O9KALfehEL7rRcR4IADs=')
     return img

def add_row():
     import tkinter as tk
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAIcAAAAAACFfHSZlIixtJzN1Ljd6MTl9Mzp+NEJ3uzyBNj2C'
            +'N0GHOkKIO0iPQEqSQkuTQ0yVRE2WRVGbSFijT12gVV6rVGOlWmOxWXy+dn7B'
            +'eVKEw1WGxlaHx12KxV+MxlmKyFuKyV6Oy1+Py2OSzmSTzmiW0WqX0W6Z02+b'
            +'1HKe1nSg13Wh13qj2nqk2X2l3H6o3YDBeoTDfoCp3YKq34Ss4Ieu4Yiv4oyx'
            +'44yy5I+05ZC15pO355S355a66Zi66Zq865u9652+656/7InGgorGhI7Jh5PL'
            +'i5fMkpjOkJ3QlKHTmKXVnKTToLDYrLrdtr3fuZ/A7aHB7qLB76PC76bD6anE'
            +'6KrG6azG6azH6K3H6azH6q3H6q7J6a7J6rDI6LDJ6bDJ6rLL6rPM6rXM6LrQ'
            +'67vQ677S67/T69ji8Nvk8dvl8d7n8t7n8+Lq9Obt9urw9+vx9+3y+O7z+e/z'
            +'+fD0+vH2+vL2+vT3+////wAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAACH5BAMAAHkALAAAAAAQABAAAAjPAPMIHEiwYJ4p'
            +'UqAE+dFjhw4cNmjIcMFCYJQ7GDNqxKhCoJA7S5QkQWKkyJAYMDDcQSEQyB08'
            +'MGPKvGNCoI87VHLq3HmHhEAeOPFUiYklJhwRAnPYsXJFSxYuX7B88TJmzQeB'
            +'N+p0wQMmAsyiMNVsEFiDThgxEBqIuVBhggQHDA4QGDBjDp4HFigoMPDESRMm'
            +'R4hkEPBiDpkyCxKUcQtX7gABAVrIMYPnTAGYW2Ki8SBwRZw3btqwSYOmtOkO'
            +'AlOcKDEiBAgOGmLLRmCwdsGAADs=')
     return img

def add_col():
     import tkinter as tk
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAIcAAAAAADdrGT5wIkx7MUR3a09/e1OMKFePLV+JSWCJSWaO'
            +'T3GXX3y+dlKEw1WGxlaHx1mKyFuKyV6Oy1+Py2OSzmSTzmiW0WqX0W6Z02+b'
            +'1HKe1nSg13Wh13qj2nqk2X2l3H6o3YGrYYe5YIe6YIu6Yo26ZIy8ZY+8Z4+7'
            +'aoDBeoTDfpGvnY6uooCp3YKq34Ss4Ieu4Yiv4oyx44yy5I+05ZC15pO355S3'
            +'55a66Zi66Zq865u9652+656/7InGgo7Jh5PLi5jOkJ3QlKHTmKXVnLHTkLLS'
            +'lbHWkrTUlbbUnJ/A7aHB7qLB76PC76bD6anE6KrG6azH6K3H6azH6q7J6a7J'
            +'6rDI6LDJ6bDJ6rLL6rPM6rXM6LfO6rrQ67vQ673R677S67/T69Dmutji8Nvk'
            +'8dvl8d7n8t7n8+Lq9Obt9urw9+vx9+3y+O7z+e/z+fD0+vH2+vL2+vT3+///'
            +'/wAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAACH5BAMAAHQALAAAAAAQABAAAAjTAOkIHEiw4EAm'
            +'SnjowGGjxowYL1p86CBwiZyLGDNe3CCwhxwiQ4QEAfLDh4oUDORkELhDzpyX'
            +'MGPKuSAwhxwnOHPqlFNB4I2bB57AjAJzzQSBNOJAQTFFCpUrUa5Y2WIGgkAZ'
            +'cKocwDIUZhkHAmG8yYJCi1kuUVgsUICggEAXbrgc8AJzRQgkYlAcCEAHhJsu'
            +'KLwI/pKgyJE5Jk7w9dAGzIEwMAckgWmELwc2atKgOUNmjAASI+aIUExHAwYL'
            +'FCREeNCAgIESRkoY4GtwYIDbt+kEBAA7')
     return img

def del_row():
     import tkinter as tk
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAIcAAAAAAEJ3u3y+dlKEw1aHx12KxVmKyFuKyV6Oy1+Py2OS'
            +'zmSTzmiW0WqX0W6Z02+b1HKe1nSg13Wh13qj2nqk2X2l3H6o3eoRHOwaI+4m'
            +'Lu4oMO8sM/AxN/E1OvE2O+RZU/RFSPVJTPZOUPdTVfdUVvhYWedhWPphYPpj'
            +'Yvxvbf54dIDBeoTDfoCp3YKq34Ss4Ieu4Yiv4oyx44yy5I+05ZC15pO355S3'
            +'55a66Zi66Zq865u9652+656/7InGgo7Jh5PLi5jOkJ3QlKHTmKXVnJ/A7aHB'
            +'7qLB76PC76bD6anE6KrG6azG6azH6K3H6azH6q3H6q7I6K7J6a7J6rDI6LDJ'
            +'6bDJ6rXM6LXN6r7S67/T6/mZk/qinPutpvu5sfzDutji8Nvk8dvl8d7n8t7n'
            +'8/zLwf3OxOLq9Obt9urw9+vx9+3y+O7z+fH2+vL2+vT3+////wAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAACH5BAMAAHEALAAAAAAQABAAAAjMAOMIHEiwYBwk'
            +'R4rw0IHDRo0ZMV60qDBBoJE3GDNqxBhBYI83RIYICQLkhw8WKwS8eSBwxxs4'
            +'MGPKfNNAYI43SXLq3PlmgcAbOOEoidkkppoEAmm4WcLkiRMpVZpUoXJljAGB'
            +'MtpMgWOFaEwxJwTCUKEiBQoSIDpkwEAlCpgRIeK4UGGmzBcvXbhsuQCnhAgT'
            +'HzhYMItWLYYLF7BgAeNhQxwKbLLA0RITSkwwGgRKWJMGzRkyYcCIHl1AIAQH'
            +'DBQgOEBggOvXAQzKLhgQADs=')
     return img

def del_col():
     import tkinter as tk
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAIcAAAAAAHy+dlKEw1WGxlaHx1mKyFuKyV6Oy1+Py2OSzmST'
            +'zmiW0WqX0W6Z02+b1HKe1nSg13Wh13qj2nqk2X2l3H6o3bpDBLhFA7lEA7lF'
            +'A7xCBLxDBbxNBbxWHb1XHrhWIr5bKIRnaYttbsRXHd1kAcdlJ8prL9J2PeFo'
            +'A+52AOp5Be9/GPh2AP93Ef9/GOZ3IYDBeoTDfv+GIeuKQP+STfSdY/WocreT'
            +'ib+Xi4Cp3YKq34Ss4Ieu4Yiv4oyx44yy5I+05ZC15pO355S355a66Zi66Zq8'
            +'65u9652+656/7InGgo7Jh5PLi5jOkJ3QlKHTmKXVnJ/A7aHB7qLB76PC76bD'
            +'6anE6KrG6azH6K3H6azH6q7J6a7J6rDI6LDJ6bDJ6rLL6rPM6rXM6LfO6rrQ'
            +'67vQ673R677S67/T6/a1jfe1jf7Nrv7WuNji8Nvk8dvl8d7n8t7n8+Lq9Obt'
            +'9urw9+vx9+3y+O7z+e/z+fD0+vH2+vL2+vT3+////wAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAACH5BAMAAH4ALAAAAAAQABAAAAjXAP0IHEiw4MAp'
            +'UZAYISIkyI8eO3JQkCBQCp+LGDNehCAwCR8oT5w0YbJESQwYAfg4EHiET5+X'
            +'MGPyYSCwCJ8qOHPq5KNA4JCbLazAxAKzDgKBQPZc0aAlyxYvWLx0EQOngEAf'
            +'eri0+DIU5psBAnnkAaMhjNkxWG6A2OAhhEAdeMa0KAMTxwk1bGyYsOCnAh4y'
            +'GsoINvMhDY0WMmZg8DPhzpkWaGBuWANzhQY/EezQmSMnjps2HWq4YJECRQY/'
            +'DxosSHDAAAEBIkq8UEGCwwWDBEdk0JDhdkAAOw==')
     return img

def new_proj():
     import tkinter as tk
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAIcAAAAAAEJ3u3y+dlKEw1SGxFWGxlaHx12KxVyKxl+MxlmK'
            +'yFuKyV+NyF6Oy1+Py2OSzmSTzmiW0WqX0W6Z02+b1HKe1nSg13Wh13qj2nqk'
            +'2X2l3H6o3YDBeoTDfoCp3YKq34Ss4Ieu4Yiv4oyx44yy5I+05ZC15pO355S3'
            +'55a66Zi66Zq865u9652+656/7InGgo7Jh5PLi5jOkJ3QlKHTmKXVnJ/A7aHB'
            +'7qLB76PC76bD6anE6KrG6azG6azH6K3H6azH6q3H6q7I6K7J6a7J6rDI6LDJ'
            +'6bDJ6rLL6rPM6rXM6LXN6rfO6rrP6rrQ67vQ673R677S67/T69ji8Nvk8dvl'
            +'8d7n8t7n8+Lq9Obt9urw9+vx9+3y+O7z+e/z+fD0+vH2+vL2+vL2+/T3+///'
            +'/wAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAACH5BAEAAGUALAAAAAAQABAAAAjEAMsIHEiw4EAc'
            +'NlqsSHHCBAkRIDxowCDwxpiLGDNetCDQxZgaNGbIiAHjRQcOAsZQEMhiDJmX'
            +'MGOOkSBQxRgdOHPqHANBIIqbZHbA9AFziwOBJcLw6AHkxxAjPowUUWJFgcAR'
            +'YIiQOTIUZpUCAkN8QZKkbBImPnwUETKFgMAPXpiQeQKziZiXUxgI3ODFyZO/'
            +'T6AsGbxkCgKBGbpEISMFZhCYUxIIvMBFSxYsV6hM2cz5gMAKEyI8aLDAwIDT'
            +'qAMYXE0wIAA7')
     return img

def open_proj():
     import tkinter as tk
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAIcAAAAAABV5ABt5AB57AyF9ACV/ACZ+ECR8FUJ3uy2DAS2D'
            +'CTWHCTCHFzyLEESPFkaQGUqRHFKXIleYKFubKV6fOlygPGKdMGOfMWWfMWih'
            +'NGujN2mjOW6jOG+lPW6kPl+hQ2KjRmalSGilRnSrT3yvVXy+dkmCpVKHpVOG'
            +'vFKEw1WGxlaHx1mKyFuKyV6Oy1+Py2OSzmSTzmiW0WqX0W6Z02+b1HKe1nSg'
            +'13Wh13qj2nqk2X2l3H6o3YGzWoCzYYK1Z4W2ZoW2aom4a466b5C8dIDBeoTD'
            +'foCp3YKq34Ss4Ieu4Yiv4oyx44yy5I+05ZC15pO355S355a66Zi66Zq865u9'
            +'652+656/7InGgo7Jh5bBgJfCgpPLi5jCg57FiJjOkJ3QlKHGiqHHiqXIjajL'
            +'kKnKkKrLka3NlKHTmKXVnLDOlp/A7aHB7qLB76PC76bD6anE6KrG6azG6azH'
            +'6K3H6azH6q7J6a7J6rLK4bDJ6bDJ6rLL6rPM6rfO6rrQ67vQ677S67/T69bi'
            +'6t7n8uLq9Obt9urw9+vx9+3y+O7z+e/z+fD0+vH2+vL2+vT3+////wAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAACH5BAEAAJAALAAAAAAQABAAAAjcACEJHEiw4MA2'
            +'a6xQkQLlSZMlSY7syCGQjaOLGDNevCHwiqM0aMB84ZIFi5EiJRzVEFjF0aOX'
            +'MGM6miFwiqM3OHPqdBRDYJSbj+DAnAPz0AuBThrFkVOHjp08czxgwDOIhUAm'
            +'jO480jN0Qw8JglQIVLJoDx8+HThksEDCzIgHKAQiUdTn0R8Nas6YIUNEjIgF'
            +'Anko8vPnz4UzQ4QA8fGjS4UCkHQkAvQo0IQyY8J4CbIlhAGBOBAZKkQoAgQH'
            +'DShoAcHghEAbNGTAcNFiRYoUCj4cMIHAYEECAwgGBAA7')
     return img

def save_proj():
     import tkinter as tk
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAIcAAAAAACBarS5fpjppqj5qqzNoukRtq0RwsFd+u1F/w1N/'
            +'wXy+dl2Ev1SBxFWDxliEw1uGx1uKyV2IyF6Oy1+Py2GKx2CJyWGLyWKLyGWN'
            +'ymWNzGiOzWyLzWiL026K122L2myN3GOSzmSTzmmQzW6TzGiW0WqX0W6X1G6Z'
            +'02+b1HGY0HOZ0XOa1HKe1nWa0Hee2Xmc1Xue1Hie2Hif2Hmf23uc3XCP4XSg'
            +'13Wh13mg2Xqg2Xqj2nuh3Hqk2Xyj232j3n2l3H6l3X6o3YS/UYS/VIDBeoTD'
            +'fpjJb5nJcYKk1oCm3YWi3YCp3YKq34Wo3YGn4YGn4oSs4Ieu4Yiv4oyv5Iyx'
            +'44yy5I+05ZC15pK15pO355S355e26pa66Zq275m46pi66Zq865u9652+656/'
            +'7KG/6qG/74nGgo7Jh5PLi5jOkJ3QlKHTmKXVnJ/A7Z7A76HB7qLB76PC76bD'
            +'6anE6KrG6azG6azH6K3H6azH6q7J6rPH47DJ6rLL6rPM6rfO6rrO77DN87rQ'
            +'67vQ677S67/T68fuh8fujNf0otf2ot7n8///3eLq9Obt9uXx7ebx7ebw7+bx'
            +'7+n05Ojz6urz8+rw9+vx9+318+3y+O7z+e/z+f//4PD0+vH2+vL2+vT3+/H4'
            +'//f7//r7/fr8/fv8/fv8/vz9/v39/v///wAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAACH5BAEAAKkALAAAAAAQABAAAAjzAFPFcTMmTBct'
            +'WKxMicIEyI5UqeB8mkix4sQbEMl8asNmjZo0aM4YKbLgUwqIYj6hWsmy5ScT'
            +'EMF8mkOzps1PIiBumYmKDss7LC1RgHjFUx07efCciKEiyYYRLlZgSFWlkx5U'
            +'fFBpCIRqT8syFqRw6uOnLIQ3qEisDAWKSoUmmv6gGoRKgplRpU6ZEkXKiQIh'
            +'mgQNGpzhSxAlPnTkmCGDQY9MhFAVQnUhC5QnP3jQeMECAQ5MlRoxUtSAC6VH'
            +'kSA5ugTjQAsUJUJMiJDAy6QhR5AQkVRjAMTfqRwAWmQIUaJDm5YQAA6xwIMO'
            +'NkB88MDBgICAADs=')
     return img

def prefs():
    import tkinter as tk
    img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAIcAAAAAAElJSU5OTlFRUVJSUlNTU1hYWFpaWltbW1xcXGFh'
            +'YWJiYmRkZGdnZ2lpaWpqamtra21tbW5ubm9vb3FxcXZ2dnd3d3l5eXp6en5+'
            +'foCAgIGBgYKCgoODg4SEhIWFhYeHh4mJiYuLi4yMjI+Pj5OTk5SUlJWVlZmZ'
            +'mZqampycnJ6enqCgoKGhoaOjo6SkpKWlpaampqenp6ioqKqqqqurq6ysrK2t'
            +'rbCwsLGxsbKysrW1tba2tre3t7m5ubq6ury8vL29vb6+vr+/v8DAwMHBwcLC'
            +'wsPDw8TExMXFxcbGxsfHx8jIyMnJycrKysvLy8zMzM3Nzc7Ozs/Pz9DQ0NHR'
            +'0dLS0tTU1NXV1dbW1tjY2NnZ2dvb29zc3N3d3d7e3uLi4uTk5OXl5efn5+np'
            +'6e3t7QAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAACH5BAEAAGYALAAAAAAQABAAAAjUAM0IHGhmCZIh'
            +'BBMOXCImjA2FA6U4MWPkixcdZmzIcEGwSxkuRoRkuYLDxpMxPUQIdIKky5Ut'
            +'XEZusfKEyQWCSa5AafJDRQsjSor0GMgECREtUYBwEEjiiJEoI0B0QEImSxMp'
            +'MAjaQPJDiRcIQ8BYURIlB8EZRnoQsaLABQkWU5RAWcG0CBAfDAwUGJikSJIl'
            +'NGQUEbKDhgOCMbAkeVKlyRIoSYI8kdBA4AsgX2J0+IDESAQJMaxoILhhAgMz'
            +'HZ4sWWDGgACIAjcE0YEANsEIBgZADAgAOw==')
    return img

def plot():
    import tkinter as tk
    img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAIcAAAAAAC5fpTBiqTBiqjJkrDNmrjRosTVosjZrtTdrtjxy'
            +'vz10wj51wz52xD92xT93xkZwu1prrUJ3xkB4x0F5yUF6ykJ6y0J7zEN8zEN8'
            +'zUR9zkV+0EV/0XCfvY1Sfa5FZe0iK+4mLu4nL+8oMO8rMu8tNPAuNfAxN/Ay'
            +'OPEzOfE2PPE3PPI4PfI5Puc3Qeg4QfI7QPA9Q/I8QfM9QvM/Q8xNYvRCRvRD'
            +'R/RFSPVKTfZNT/dSVPhXWPhYWflcXPldXflhYPpjYvtmZftnZftraY9kk6he'
            +'goyhwJOs0Zyx0P6WlPyZl/61sgAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAACH5BAEAAE0ALAAAAAAQABAAAAhzAJsIHEiwoMGD'
            +'AnEgNHhjSYuFBGewgEhwBUQNA1UMJDIkCMEMSTpEeNEkwYECQpj8IEjBQRMX'
            +'HxAYODIAiA8eO3QYkSAwhQmBBAQEIFikRowVKEosrDDwhBIRBjdgoECQRAgQ'
            +'Bi8gaUBR4AQGCrqKHWswIAA7')
    return img

def plotprefs():
    import tkinter as tk
    img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAIcAAAAAAFU9ETxyvz10wj51wz52xD92xT93xltujUJ3xkB4'
            +'x0F5yUF6ykJ6y0J7zEN8zEN8zUR9zkV+0EV/0XCfvYdfKJxpHYNlK6pkHL56'
            +'GrN3Lbl5LvAyOPEzOfE3PPI4PfI5PvA9Q/I8QfM9QvM/Q8dvIupeM8xNYvRC'
            +'RvRDR/RFSPVKTfZNT/dSVPhXWPhYWflcXPldXflhYPpjYvtmZftnZftraY9k'
            +'k6hegraDGZGKdJaTbaqJQ7yNQr2IScGCNNKIN9mMNtiMONiNONGVK+aBOOS3'
            +'JMGKTMmFQc2NRMWYSdCdRtqUQduVQ9yVQt+ZQNiaVMeXYs+daNilWNejY9W2'
            +'eta4c+e+d+TJVfXfW/XcXvXcX+3KbefLd+3QeO7Tee7Sfe7TfPffY/bdbPDT'
            +'efHUe/LWevfhWvfiW/jiXZOs0Zyx0NuxhdG3kPyZl/61sufAi/nHlPnJke/S'
            +'rPbTrvDStPnjsvzgxP32wv32xP33x//y4P/z5QAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAACH5BAEAAH0ALAAAAAAQABAAAAiZAPsIHEiwoMGD'
            +'AlUgNJjCDYiFBEd8gEjQA8QIA6ewWdLHRo0ZBCGsoaDjSh0+c47QeBOD4AID'
            +'fcDYgUPnjhQZMFy0YIEjgcAwecZwoRIFAcEbJ0KY+KJnCxozTwoyGNhFj5Yz'
            +'ZZwMlPBgwUAreMSkIdOEoAM1BQRWaYMlixcmBRUQENCHxx4oGZT8gHghjhwk'
            +'GCgGqOCjB8KAADs=')
    return img

def start():
     import tkinter as tk
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhGAAYAKUAAP///+bm/+Xl/uPj/OHh++Df+d7d993d99vb9dvb9NnZ'
            +'8tnZ5tfW8NTU7tLS69DQ6dDP6c3N58vL5cnJ48fH4MTE3sLC3MDAzL/A2b2+'
            +'17u71Lm507e30LW1z7S0zrOzzLCwya6ux6ysxaqqw6iowaenwaWlv6OjvaOj'
            +'vKGguqChup6euJyctZqas5aWr5SUrY+PqI2NpoiIoYaGn4KDm4GBmoCAmTMz'
            +'ZgAAAP///////////////////////////yH+EUNyZWF0ZWQgd2l0aCBHSU1Q'
            +'ACH5BAEAAD8ALAMAAAAVABgAAAanwJ9wSCwaj8ikUogr3p7PJG7RHJpa1xsS'
            +'17lQh7arSWvkzrrfnw3bIhPNoXNVLXYzM+dZaK5m23EVMXgZfHRYbjgRLhUw'
            +'GIV9WUwNLooUj4ZjPzcNJg0sEZeQbQAAm50rEJdhhz+kNwadnY9rka2lBiGc'
            +'DYWrmUKuBSGwDHy0bUSuuAYlBnO9drY3ASEFzFXG0NEBHQHONt/Z2nykpEmu'
            +'S0gA6OvsSUEAOw==')
     return img

def end():
     import tkinter as tk
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhGAAYAKUAAP///+bm/+Xl/uPj/OHh++Df+d7d993d99vb9dvb9NnZ'
            +'8tnZ5tfW8NTU7tLS69DQ6dDP6c3N58vL5cnJ48fH4MTE3sLC3MDAzL/A2b2+'
            +'17u71Lm507e30LW1z7S0zrOzzLCwya6ux6ysxaqqw6iowaenwaWlv6OjvaOj'
            +'vKGguqChup6euJyctZqas5aWr5SUrY+PqI2NpoiIoYaGn4KDm4GBmoCAmTMz'
            +'ZgAAAP///////////////////////////yH+EUNyZWF0ZWQgd2l0aCBHSU1Q'
            +'ACH5BAEAAD8ALAAAAAAVABgAAAaqwJ9wSCwaj8ikEKdM4hZM5G06HT4vnajx'
            +'1jJ1lwvsLHu8eU02a2cWGmuHXG/a2l5n3j9zd27NzDIxFW9xLXxWGDAVLhFa'
            +'emhHOBSLLg1RhIZEOBEsDSYNN3lnmEsQK52fAACXRjinJgY3qaF7Ra2eIbCy'
            +'eV2FmQyvIQWxAHCiVgYlBrjDRKs/OMgFIQHMzcZLAR3Uus28hjjbxFs25JjV'
            +'R6ncQ+JN7e7vREEAOw==')
     return img

def next():
     import tkinter as tk
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAIcAAAAAACBeHSRjISlpJS9wKjV4LzuANUKIO0WIP0mLREqM'
            +'RUmRQU+ZR1CRSlydVVahTV6hWVypU2KjWmKxWGi4XW2+YXy+dnHDZXTHaIDB'
            +'eoLCfYTDfofFgYnGgovHhY7Jh5DKiZPLi5XMjpjOkJrPk53QlJ/SlqHTmKPU'
            +'mqXVnKfWnqnXoKvYoq7apQAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAACH5BAEAAC4ALAAAAAAQABAAAAheAF0IHEiwoMGD'
            +'CBMqXJiQAcOBCw4QxIDhQgUKEyI8YLBAgoMCAzG0YKEChQkSIkB44KChwQCB'
            +'F1akOFFiRIgPHTZksKBAgMCLGTdGNIAAQgKfDAcgZbj0odOnUA8GBAA7')
     return img

def prev():
     import tkinter as tk
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAIcAAAAAACBeHSRjISlpJS9wKjV4LzuANUKIO0mRQU+ZR1ah'
            +'TVypU2SqW2KxWGi4XXi9cnu+cXy+dnHDZXTHaH7AeIDBeoPBeoLCfYTDfobI'
            +'e4fJfIrMf4fFgYnGgovHhYvNgI7Jh5DKiZPLi5XMjpjOkJrPk53QlJ/SlqHT'
            +'mKPUmqXVnKfWnqvYogAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAACH5BAMAAC0ALAAAAAAQABAAAAhdAFsIHEiwoMGD'
            +'CBMqXChwAsOGEh5O+KDBQYMFChIgOGCgAIGGG1isSHGixIgQHjhcoDBAoIQM'
            +'KlCYICECRAcMFSI8EDDQAQQLDDRy9DhAQACCGB8KTKC0qdOnDwMCADs=')
     return img

def search():
     import tkinter as tk
     img = tk.PhotoImage(format='gif',data=
             'R0lGODlhEAAQAIcAAAAAAHaczXufzXug0H+l05JaEJNbEZVdFJdfGJpiG51l'
            +'H51nIp5mIqNrKKVtK6hwMKpyMq93ObF5PLV9Qbd/RLyES7yNVcWXZMeZZsyi'
            +'dc6kdpKUnYqTooWp1oaq14qu2Yyw24+y3ZGox5O235y6352735a44Zq845u9'
            +'5J/A56LD6KbG66jI7KvL7q7J6K7O8K/P8bXP7LfQ7bTT9LvW87vX87jW9rnX'
            +'973V8L3X873Y877Z87vZ+b3b+r7b+r/c+tWuht21ieTBnejLq8Da9MHa9MLb'
            +'9MPc9MTc9MXd9cbd9cfe9cDe/MHe/Mjd88ne88je9cjf9cnf9crg9cvh9s3h'
            +'9czh9s7i9szi+M3i+dDi9dDj9tHl99Lk99Pl99bn99fn99Pm+Nbn+Nno+Nrp'
            +'+N3q+d7r+d/s+d7s+uHt+eLt+eLu+ePu+gAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA'
            +'AAAAAAAAAAAAAAAAAAAAACH5BAMAAG0ALAAAAAAQABAAAAiTANsIHEiwYEEe'
            +'NmbAaGFwoI8saNaoIYMjRcM2WNh8uUJlS5kYIwzeMPPFyhQoSahoAWFwRhor'
            +'UpYgMUJEjAeDL85EUXKkyI4cYQgYZAHGCk0dNYw8EWBQhYwxUHTQMNKlxIaG'
            +'JlxU8cLFCQkRQCY0/NCBwIAAHDIM0fDgIkEJF4RgUOB2oAMLQRDUHZhgwd6/'
            +'fwMCADs=')
     return img
